function result = Mie_tetascan(m, x, nsteps)
% Computation and plot of Mie Power Scattering function for given
% complex refractive-index ratio m=m'+im", size parameters x=k0*a,
% according to Bohren and Huffman (1983) BEWI:TDD122
% C. M?tzler, May 2002.
nsteps=nsteps;
m1=real(m); m2=imag(m);
nx=(1:nsteps); dteta=pi/(nsteps-1);
teta=(nx-1).*dteta;
for j = 1:nsteps,
    u=cos(teta(j));
    a(:,j)=Mie_S12(m,x,u);
    SL(j)= real(a(1,j)'*a(1,j));
    SR(j)= real(a(2,j)'*a(2,j));
end;
y=[teta teta+pi;SL SR(nsteps:-1:1)]';
cla reset;
polar(y(:,1),y(:,2));
% title(sprintf('Mie angular scattering: m=%g+%gi, x=%g',m1,m2,x));
% ylabel('Mie scattering intensities');
% xlabel('Scattering Angle');
result=y;

function result = Mie_S12(m, x, u)
% Computation of Mie Scattering functions S1 and S2
% for complex refractive index m=m'+im",
% size parameter x=k0*a, and u=cos(scattering angle),
% where k0=vacuum wave number, a=sphere radius;
% s. p. 111-114, Bohren and Huffman (1983) BEWI:TDD122
% C. M?tzler, May 2002
nmax=round(2+x+4*x^(1/3));
abcd=mie_abcd(m,x);
an=abcd(1,:);
bn=abcd(2,:);
pt=Mie_pt(u,nmax);
pin =pt(1,:);
tin=pt(2,:);
n=(1:nmax);
n2=(2*n+1)./(n.*(n+1));
pin=n2.*pin;
tin=n2.*tin;
S1=(an*pin'+bn*tin');
S2=(an*tin'+bn*pin');
result=[S1;S2];

function result=Mie_pt(u,nmax)
% pi_n and tau_n, -1 <= u= cos <= 1, n1 integer from 1 to nmax
% angular functions used in Mie Theory
% Bohren and Huffman (1983), p. 94 - 95
p(1)=1;
t(1)=u;
p(2)=3*u;
t(2)=3*cos(2*acos(u));
for n1=3:nmax,
    p1=(2*n1-1)./(n1-1).*p(n1-1).*u;
    p2=n1./(n1-1).*p(n1-2);
    p(n1)=p1-p2;
    t1=n1*u.*p(n1);
    t2=(n1+1).*p(n1-1);
    t(n1)=t1-t2;
end;
result=[p;t];